@@ -97,8 +97,7 @@ class ELNClient(ClientBase):
         """
         numeric_doc_id = self._get_numeric_record_id(doc_id)
         return self.retrieve_api_results(
-            "/documents/{}".format(numeric_doc_id),
-            content_type="text/csv",
+            "/documents/{}".format(numeric_doc_id), content_type="text/csv",
         )
 
     def create_document(
@@ -245,9 +244,7 @@ class ELNClient(ClientBase):
             data["fields"] = fields
         numeric_doc_id = self._get_numeric_record_id(document_id)
         return self.retrieve_api_results(
-            "/documents/{}".format(numeric_doc_id),
-            request_type="PUT",
-            params=data,
+            "/documents/{}".format(numeric_doc_id), request_type="PUT", params=data,
         )
 
     # Sharing methods
@@ -687,8 +684,7 @@ class ELNClient(ClientBase):
         """
         numeric_doc_id = self._get_numeric_record_id(form_id)
         return self.retrieve_api_results(
-            "/forms/{}/publish".format(numeric_doc_id),
-            request_type="PUT",
+            "/forms/{}/publish".format(numeric_doc_id), request_type="PUT",
         )
 
     def unpublish_form(self, form_id):
@@ -700,8 +696,7 @@ class ELNClient(ClientBase):
         """
         numeric_doc_id = self._get_numeric_record_id(form_id)
         return self.retrieve_api_results(
-            "/forms/{}/unpublish".format(numeric_doc_id),
-            request_type="PUT",
+            "/forms/{}/unpublish".format(numeric_doc_id), request_type="PUT",
         )
 
     def share_form(self, form_id):
@@ -713,8 +708,7 @@ class ELNClient(ClientBase):
         """
         numeric_doc_id = self._get_numeric_record_id(form_id)
         return self.retrieve_api_results(
-            "/forms/{}/share".format(numeric_doc_id),
-            request_type="PUT",
+            "/forms/{}/share".format(numeric_doc_id), request_type="PUT",
         )
 
     def unshare_form(self, form_id):
@@ -727,8 +721,7 @@ class ELNClient(ClientBase):
         """
         numeric_doc_id = self._get_numeric_record_id(form_id)
         return self.retrieve_api_results(
-            "/forms/{}/unshare".format(numeric_doc_id),
-            request_type="PUT",
+            "/forms/{}/unshare".format(numeric_doc_id), request_type="PUT",
         )
 
     # Folder / notebook methods
