@@ -755,11 +755,13 @@ class ItemPost:
     def __init__(
         self,
         name: str,
+        itemType: str,
         tags: Optional[str] = None,
         description: Optional[str] = None,
         extra_fields: Optional[Sequence] = [],
     ):
         self.data = {}
+        self.data["type"] = itemType
         self.data["name"] = name
         if tags is not None:
             self.data["tags"] = tags
@@ -789,9 +791,9 @@ class SamplePost(ItemPost):
         total_quantity: Quantity = None,
         attachments=None,
     ):
-        super().__init__(name, tags, description, extra_fields)
+        super().__init__(name, "SAMPLE", tags, description, extra_fields)
         ## converts arguments into JSON POST syntax
-        self.data["type"] = "SAMPLE"
+
         if storage_temperature_min is not None:
             self.data["storageTempMin"] = storage_temperature_min._toDict()
         if storage_temperature_max is not None:
@@ -912,7 +914,7 @@ class ContainerPost(ItemPost):
         can_store_samples: bool = True,
         location: TargetLocation = TopLevelTargetLocation(),
     ):
-        super().__init__(name, tags, description, extra_fields)
+        super().__init__(name, "CONTAINER", tags, description, extra_fields)
         if not can_store_containers and not can_store_samples:
             raise ValueError(
                 "At least one of 'canStoreContainers' and 'canStoreSamples' must be True"
@@ -1085,6 +1087,7 @@ class InventoryClient(ClientBase):
             )
         toPost = [s.data for s in sample_posts]
         bulk_post = {"operationType": "CREATE", "records": toPost}
+        print(bulk_post)
         return self._do_bulk(bulk_post)
 
     def create_sample(
@@ -1203,9 +1206,7 @@ class InventoryClient(ClientBase):
         if sample_filter is not None:
             pagination.data.update(sample_filter.data)
         return self.retrieve_api_results(
-            f"/{endpoint}",
-            request_type="GET",
-            params=pagination.data,
+            f"/{endpoint}", request_type="GET", params=pagination.data,
         )
 
     def stream_samples(
@@ -1410,8 +1411,7 @@ class InventoryClient(ClientBase):
         id_to_copy = Id(item_to_duplicate)
         endpoint = id_to_copy.get_api_endpoint()
         rc = self.retrieve_api_results(
-            f"/{endpoint}/{id_to_copy.as_id()}/actions/duplicate",
-            request_type="POST",
+            f"/{endpoint}/{id_to_copy.as_id()}/actions/duplicate", request_type="POST",
         )
         if new_name is not None:
             rc = self.rename(rc, new_name)
@@ -1452,9 +1452,7 @@ class InventoryClient(ClientBase):
             raise ValueError("Supplied id is not a subsamples")
         data = {"content": note}
         return self.retrieve_api_results(
-            f"/subSamples/{ss_id.as_id()}/notes",
-            request_type="POST",
-            params=data,
+            f"/subSamples/{ss_id.as_id()}/notes", request_type="POST", params=data,
         )
 
     def get_workbenches(self) -> Sequence[dict]:
@@ -1626,11 +1624,7 @@ class InventoryClient(ClientBase):
             raise ValueError("Target must be a container")
         return id_target
 
-    def add_items_to_list_container(
-        self,
-        target_container_id,
-        *item_ids: str,
-    ) -> list:
+    def add_items_to_list_container(self, target_container_id, *item_ids: str,) -> list:
         """
         Adds 1 or more items to a list container
 
@@ -2020,8 +2014,7 @@ class InventoryClient(ClientBase):
         """
         id_to_restore = Id(sample_template_id)
         return self.retrieve_api_results(
-            f"/sampleTemplates/{id_to_restore.as_id()}/restore",
-            request_type="PUT",
+            f"/sampleTemplates/{id_to_restore.as_id()}/restore", request_type="PUT",
         )
 
     def transfer_sample_template_owner(
